Learn R Programming

ConfZIC (version 1.0.1)

Concrete: Concrete Compressive Strength Data Set

Description

Concrete strength is very important in civil engineering and is a highly nonlinear function of age and ingredients. This dataset contains 1030 instances and there are 8 features relevant to concrete strength.

Usage

Concrete

Arguments

Format

A data frame with 1030 rows and 8 covariate variables and 1 response variable

Examples

Run this code
data(Concrete)

Run the code above in your browser using DataLab